# Maintainers


For member policy, see the description at the top of [HoloViz/HoloViz - MEMBERS.md](https://github.com/holoviz/holoviz/blob/colorcet-gov/doc/governance/project-docs/MEMBERS.md).


The Colorcet Project’s equivalently named documents take precedence over any external materials referenced within this linked document above.


| **NAME** | **Role** | **GitHub Handle** |
| --- | --- | --- |
| James Bednar | Project Director | [jbednar](https://github.com/jbednar) |
| Ian Thomas | Maintainer | [ianthomas23](https://github.com/ianthomas23) |
